@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2018 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -248,14 +248,21 @@ PHP_FUNCTION(gethostbynamel)
 	}
 
 	hp = php_network_gethostbyname(hostname);
-	if (hp == NULL || hp->h_addr_list == NULL) {
+	if (!hp) {
 		RETURN_FALSE;
 	}
 
 	array_init(return_value);
 
-	for (i = 0 ; hp->h_addr_list[i] != 0 ; i++) {
-		in = *(struct in_addr *) hp->h_addr_list[i];
+	for (i = 0;; i++) {
+		/* On macos h_addr_list entries may be misaligned. */
+		struct in_addr *h_addr_entry; /* Don't call this h_addr, it's a macro! */
+		memcpy(&h_addr_entry, &hp->h_addr_list[i], sizeof(struct in_addr *));
+		if (!h_addr_entry) {
+			return;
+		}
+
+		in = *h_addr_entry;
 		add_next_index_string(return_value, inet_ntoa(in));
 	}
 }
@@ -265,16 +272,22 @@ PHP_FUNCTION(gethostbynamel)
 static zend_string *php_gethostbyname(char *name)
 {
 	struct hostent *hp;
+	struct in_addr *h_addr_0; /* Don't call this h_addr, it's a macro! */
 	struct in_addr in;
 	char *address;
 
 	hp = php_network_gethostbyname(name);
-
-	if (!hp || !*(hp->h_addr_list)) {
+	if (!hp) {
 		return zend_string_init(name, strlen(name), 0);
 	}
 
-	memcpy(&in.s_addr, *(hp->h_addr_list), sizeof(in.s_addr));
+	/* On macos h_addr_list entries may be misaligned. */
+	memcpy(&h_addr_0, &hp->h_addr_list[0], sizeof(struct in_addr *));
+	if (!h_addr_0) {
+		return zend_string_init(name, strlen(name), 0);
+	}
+
+	memcpy(&in.s_addr, h_addr_0, sizeof(in.s_addr));
 
 	address = inet_ntoa(in);
 	return zend_string_init(address, strlen(address), 0);
@@ -353,7 +366,7 @@ PHP_FUNCTION(dns_check_record)
 	querybuf answer;
 	char *hostname, *rectype = NULL;
 	size_t hostname_len, rectype_len = 0;
-	int type = T_MX, i;
+	int type = DNS_T_MX, i;
 #if defined(HAVE_DNS_SEARCH)
 	struct sockaddr_storage from;
 	uint32_t fromsize = sizeof(from);
@@ -375,7 +388,7 @@ PHP_FUNCTION(dns_check_record)
 	}
 
 	if (rectype) {
-		if (!strcasecmp("A",     rectype)) type = T_A;
+		if (!strcasecmp("A",     rectype)) type = DNS_T_A;
 		else if (!strcasecmp("NS",    rectype)) type = DNS_T_NS;
 		else if (!strcasecmp("MX",    rectype)) type = DNS_T_MX;
 		else if (!strcasecmp("PTR",   rectype)) type = DNS_T_PTR;
@@ -452,11 +465,11 @@ static u_char *php_parserr(u_char *cp, u_char *end, querybuf *answer, int type_t
 	GETLONG(ttl, cp);
 	GETSHORT(dlen, cp);
 	CHECKCP(dlen);
-	if (dlen == 0) {
-		/* No data in the response - nothing to do */
-		return NULL;
-	}
-	if (type_to_fetch != T_ANY && type != type_to_fetch) {
+    if (dlen == 0) {
+        /* No data in the response - nothing to do */
+        return NULL;
+    }
+    if (type_to_fetch != DNS_T_ANY && type != type_to_fetch) {
 		cp += dlen;
 		return cp;
 	}
@@ -814,18 +827,22 @@ PHP_FUNCTION(dns_get_record)
 		Z_PARAM_STRING(hostname, hostname_len)
 		Z_PARAM_OPTIONAL
 		Z_PARAM_LONG(type_param)
-		Z_PARAM_ZVAL_DEREF_EX(authns, 1, 0)
-		Z_PARAM_ZVAL_DEREF_EX(addtl, 1, 0)
+		Z_PARAM_ZVAL(authns)
+		Z_PARAM_ZVAL(addtl)
 		Z_PARAM_BOOL(raw)
 	ZEND_PARSE_PARAMETERS_END();
 
 	if (authns) {
-		zval_ptr_dtor(authns);
-		array_init(authns);
+		authns = zend_try_array_init(authns);
+		if (!authns) {
+			return;
+		}
 	}
 	if (addtl) {
-		zval_ptr_dtor(addtl);
-		array_init(addtl);
+		addtl = zend_try_array_init(addtl);
+		if (!addtl) {
+			return;
+		}
 	}
 
 	if (!raw) {
@@ -1047,17 +1064,21 @@ PHP_FUNCTION(dns_get_mx)
 
 	ZEND_PARSE_PARAMETERS_START(2, 3)
 		Z_PARAM_STRING(hostname, hostname_len)
-		Z_PARAM_ZVAL_DEREF(mx_list)
+		Z_PARAM_ZVAL(mx_list)
 		Z_PARAM_OPTIONAL
-		Z_PARAM_ZVAL_DEREF(weight_list)
+		Z_PARAM_ZVAL(weight_list)
 	ZEND_PARSE_PARAMETERS_END();
 
-	zval_ptr_dtor(mx_list);
-	array_init(mx_list);
+	mx_list = zend_try_array_init(mx_list);
+	if (!mx_list) {
+		return;
+	}
 
 	if (weight_list) {
-		zval_ptr_dtor(weight_list);
-		array_init(weight_list);
+		weight_list = zend_try_array_init(weight_list);
+		if (!weight_list) {
+			return;
+		}
 	}
 
 #if defined(HAVE_DNS_SEARCH)
@@ -1140,12 +1161,3 @@ PHP_MINIT_FUNCTION(dns) {
 	return SUCCESS;
 }
 #endif /* HAVE_FULL_DNS_FUNCS */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: sw=4 ts=4 fdm=marker
- * vim<600: sw=4 ts=4
- */
